#ifndef WR_IOCTL_H
#define WR_IOCTL_H 

#include <asm/types.h>


#pragma pack(push,1)

typedef struct
{
    __u8        Request;
    __u16       Value;
    __u16       Index;
    void        *Buffer;
    __u16       Size;
    int         Timeout;
} USB_CONTROL_MSG, *PUSB_CONTROL_MSG;

typedef struct
{
    __u8        EndPoint;
    __u8        *Buffer;
    int         BufferSize;
    int         ActualSize;
    int         Timeout;
} USB_BULK_MESSAGE,*PUSB_BULK_MESSAGE;

typedef struct
{
    __u16       ByteCount;
    __u8        *Addresses;
    __u8        *Values;
} PIC_REG,*PPIC_REG;


typedef struct
{
    __u8 Number;
    __u8 Address;
} ENDPOINT_INFO,*PENDPOINT_INFO;

typedef struct
{
    __u8            Count;
    ENDPOINT_INFO   EndPoint[16];
} ENDPOINTS,*PENDPOINTS;

typedef struct
{
    __u8    EndPoint;
    __u32   BufferSize;
    __u32   NumberOfBuffers;
    __u32   UsbBufferSize;
    __u32   NumberOfUsbBuffers;
} STREAM_INFO,*PSTREAM_INFO; 

typedef struct
{
    __u8    Filled;
    __u32   BufferSize;
    __u8    *Buffer;
    __u8    Wait;
} STREAM_BUFFER,*PSTREAM_BUFFER;

typedef struct
{
    __u32 Address;
    __u32 Count;
    __u16 *Buffer;
} READ_WRITE_INFO,*PREAD_WRITE_INFO;

#pragma pack(pop)

#define WRG3_MAGIC 0x8C

#define WRG3_IOCTL_GET_INTERFACE                  _IOR(WRG3_MAGIC,0x01,__u8)
#define WRG3_IOCTL_IS_CONNECTED                   _IOR(WRG3_MAGIC,0x02,__u8)
#define WRG3_IOCTL_USB_CONTROL_MESSAGE_SEND       _IOW(WRG3_MAGIC,0x03,USB_CONTROL_MSG)
#define WRG3_IOCTL_USB_CONTROL_MESSAGE_RECEIVE    _IOWR(WRG3_MAGIC,0x04,USB_CONTROL_MSG)
#define WRG3_IOCTL_USB_CONTROL_MESSAGE            _IOW(WRG3_MAGIC,0x05,USB_CONTROL_MSG)
#define WRG3_IOCTL_PCI_READ_PIC_BYTES             _IOWR(WRG3_MAGIC,0x06,PIC_REG)
#define WRG3_IOCTL_PCI_WRITE_PIC_BYTES            _IOW(WRG3_MAGIC,0x07,PIC_REG)
#define WRG3_IOCTL_PCI_READ_PIC_BYTE              _IOWR(WRG3_MAGIC,0x08,__u16)
#define WRG3_IOCTL_PCI_WRITE_PIC_BYTE             _IOW(WRG3_MAGIC,0x09,__u16)
#define WRG3_IOCTL_USB_CONFIGURE                  _IOW(WRG3_MAGIC,0x09,__u8)
#define WRG3_IOCTL_USB_GET_ENDPOINTINFO           _IOR(WRG3_MAGIC,0x0A,ENDPOINTS)
#define WRG3_IOCTL_USB_START_STREAMING            _IOW(WRG3_MAGIC,0x0B,STREAM_INFO)
#define WRG3_IOCTL_USB_STOP_STREAMING             _IO(WRG3_MAGIC,0x0B)
#define WRG3_IOCTL_USB_GET_STREAM_BUFFER          _IOR(WRG3_MAGIC,0x0C,STREAM_BUFFER)
#define WRG3_IOCTL_USB_BULK_MESSAGE_SEND          _IOWR(WRG3_MAGIC,0x0D,USB_BULK_MESSAGE)
#define WRG3_IOCTL_USB_BULK_MESSAGE_SEND_ASYNC    _IOW(WRG3_MAGIC,0x0E,USB_BULK_MESSAGE)
#define WRG3_IOCTL_USB_BULK_MESSAGE_RECEIVE       _IOWR(WRG3_MAGIC,0x0F,USB_BULK_MESSAGE)
#define WRG3_IOCTL_PCI_WRITE                      _IOW(WRG3_MAGIC,0x10,READ_WRITE_INFO)
#define WRG3_IOCTL_PCI_READ                       _IOWR(WRG3_MAGIC,0x11,READ_WRITE_INFO)
#define WRG3_IOCTL_PCI_RESET                      _IO(WRG3_MAGIC,0x12)
#define WRG3_IOCTL_PCI_CATCH_INTERRUPT            _IO(WRG3_MAGIC,0x13)
#define WRG3_IOCTL_PCI_START_INTERRUPT            _IO(WRG3_MAGIC,0x14)
#define WRG3_IOCTL_PCI_STOP_INTERRUPT             _IO(WRG3_MAGIC,0x15)
#define WRG3_IOCTL_USB_RESET_EP                   _IOW(WRG3_MAGIC,0x16,__u8)
#define WRG3_IOCTL_USB_CLEAR_HALT                 _IOW(WRG3_MAGIC,0x17,__u8)
#define WRG3_IOCTL_USB_SHIFT_STREAM               _IOW(WRG3_MAGIC,0x18,__u32)


#endif
